"""
ebi_get_domain_fields

Get list of available searchable fields for a specific EBI domain. Useful for understanding what ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def ebi_get_domain_fields(
    domain: str,
    format: Optional[str] = "json",
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> list[Any]:
    """
    Get list of available searchable fields for a specific EBI domain. Useful for understanding what ...

    Parameters
    ----------
    domain : str
        EBI domain name
    format : str

    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    list[Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "ebi_get_domain_fields",
            "arguments": {"domain": domain, "format": format},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["ebi_get_domain_fields"]
